from setuptools import setup

setup(name='NG_distributions',
      version='0.1',
      description='Gaussian and Binomial distribution',
      packages=['NG_distributions'],
      author = 'Shivakant Vishwakarma',
      author_email = 'shivakant7621@gmail.com',
      zip_safe=False)
